"""
Файлы __init__.py необходимы, чтобы Python рассматривал каталоги как
содержащие пакеты; это сделано для предотвращения непреднамеренного
скрытия действительными модулями каталогов с общим именем, например,
строки, которые появляются позже в пути поиска модулей
"""



from setuptools import setup
from setuptools import find_packages

setup(
    name="MikeT_messenger_server",
    version="0.4.1",
    description="Messenger_server_part",
    author="machukhinktato",
    author_email="machukhinktato@mail.ru",
    packages=find_packages(),
    install_requires=['PyQt5', 'sqlalchemy', 'pycryptodome']
)
